@@ -15,6 +15,10 @@
 #include <cmath>
 #include <climits>
 #include <vector>
+#include <unordered_set>
+#include <queue>
+#include <list>
+#include <algorithm>
 // LOCAL MODULES
 #include "utils.h"
 
@@ -24,7 +28,7 @@
  * DEFINES
  */
 #define MESH_MAX_POINT MAX_INT-1
-#define EPSILON 0.0001
+#define EPSILON 0.001
 #define FOLLOW_SEARCH
 
 
