@@ -76,7 +76,12 @@ class Edge {
                 Face* rightFace() 	const { return this->opposite_edge->left_face; }
 
                 bool isVisible()        const { return this->visible; }
+                bool isExternal()       const;
                 unsigned int getID()    const { return this->id; }
+                float length()          const;
+                float squareLength()    const;
+
+                Coordinates middle()    const;
                 // setters
                 void setOriginVertex(Vertex* v) { this->origin_vertex = v; v->setEdge(this); }
                 void setOppositeEdge(Edge* e)   { this->opposite_edge = e; }
